@@ -2,8 +2,8 @@
  * distributed under the terms of the GNU Public License.  See the
  * file COPYING for details.
  */
-/* $Revision: 1.7 $
- * $Date: 2005/10/21 13:18:42 $
+/* $Revision: 1.8 $
+ * $Date: 2008/05/23 14:54:28 $
  * $Author: sgop $
  */
 
@@ -16,7 +16,7 @@
 
 typedef struct _tree_t tree_t;
 
-typedef gboolean (*ProgressFunc)(double percentage, void* data);
+typedef gboolean (*ProgressFunc)(void* data);
 
 struct _tree_t {
   char* name;
